@@ -7,6 +7,11 @@
  */
 #ifndef CAC_H
 #define CAC_H 1
+
+#if !defined(__LIBCACARD_H_INSIDE__) && !defined(LIBCACARD_COMPILATION)
+#warning "Only <libcacard.h> can be included directly"
+#endif
+
 #include "vcard.h"
 #include "vreader.h"
 
@@ -25,7 +30,4 @@ VCardStatus cac_card_init(VReader *reader, VCard *card, const char *params,
               unsigned char * const *cert, int cert_len[],
               VCardKey *key[] /* adopt the keys*/,
               int cert_count);
-
-/* not yet implemented */
-VCardStatus cac_is_cac_card(VReader *reader);
 #endif
