@@ -4,6 +4,11 @@
  */
 #ifndef EVENT_H
 #define EVENT_H 1
+
+#if !defined(__LIBCACARD_H_INSIDE__) && !defined(LIBCACARD_COMPILATION)
+#warning "Only <libcacard.h> can be included directly"
+#endif
+
 #include "eventt.h"
 #include "vreadert.h"
 #include "vcardt.h"
